@@ -7,8 +7,10 @@ import traceback
 
 from .. util import check_output
 from .. util import execute_command
+from .. util import print_exc
 from .. logging import error
 from .. logging import debug
+from .. git import get_commit_hash
 from .. git import get_current_branch
 from .. git import has_changes
 from .. git import inbranch
@@ -20,7 +22,13 @@ except ImportError:
     error("catkin_pkg was not detected, please install it.", file=sys.stderr)
     sys.exit(1)
 
-_patch_config_keys = ['parent', 'base', 'trim', 'trimbase']
+_patch_config_keys = [
+    'parent',    # The name of the parent reference
+    'previous',  # Parent commit hash, used to check if rebase is needed
+    'base',      # Commit hash before patches
+    'trim',      # Trim sub folder name
+    'trimbase'   # Commit hash before trimming
+]
 _patch_config_keys.sort()
 
 
@@ -29,7 +37,7 @@ def get_version(directory=None):
     try:
         version = verify_equal_package_versions(packages.values())
     except RuntimeError as err:
-        traceback.print_exec()
+        print_exc(traceback.format_exc())
         error("Releasing multiple packages with different versions is "
                 "not supported: " + str(err))
         sys.exit(1)
@@ -68,16 +76,19 @@ def get_patch_config(patches_branch, directory=None):
         if not os.path.exists(conf_path):
             return None
         cmd = 'git config -f {0} patches.'.format(conf_path)
-        try:
-            config = {}
-            for key in _patch_config_keys:
+        config = {}
+        for key in _patch_config_keys:
+            try:
                 config[key] = check_output(cmd + key, shell=True,
                                            cwd=directory).strip()
-            return config
-        except subprocess.CalledProcessError as err:
-            traceback.print_exc()
-            error("Failed to get patches info: " + str(err))
-            return None
+            except subprocess.CalledProcessError as err:
+                if key == 'previous':
+                    config[key] = ''
+                else:
+                    print_exc(traceback.format_exc())
+                    error("Failed to get patches info: " + str(err))
+                    return None
+        return config
     return fn()
 
 
@@ -105,7 +116,7 @@ def set_patch_config(patches_branch, config, directory=None):
                 cmd = 'git commit -m "Updated patches.conf"'
                 execute_command(cmd, cwd=directory)
         except subprocess.CalledProcessError as err:
-            traceback.print_exc()
+            print_exc(traceback.format_exc())
             error("Failed to set patches info: " + str(err))
             raise
     return fn(config)
